# bios_grub.py
# Format class for an immutable 'waste' partition for grub2's core.img file.
# almost identical to prepboot save for the partition type and names

from ..errors import *
from . import DeviceFormat, register_device_format
from parted.__init__ import PARTITION_BIOS_GRUB

class BIOS_GRUB(DeviceFormat):
    """ Generic device format. """
    _type = "bios_grub"
    _name = "BIOS grub"
    _udevTypes = []
    partedFlag = PARTITION_BIOS_GRUB
    _formattable = True                 # can be formatted
    _linuxNative = True                 # for clearpart
    _bootable = True                    # can be used as boot
    _maxSize = 64                       # maximum size in MB
    _minSize = 1                        # minimum size in MB

    def __init__(self, *args, **kwargs):
        """ Create a BIOS_GRUB instance.

            Keyword Arguments:

                device -- path to the underlying device
                exists -- indicates whether this is an existing format

        """
        DeviceFormat.__init__(self, *args, **kwargs)

    @property
    def status(self):
        return False

    @property
    def supported(self):
        import platform
        return isinstance(platform.getPlatform(None), platform.Sparc)

    def writeKS(self, f):
        f.write("# bios_boot --fstype=%s" % self.type)


register_device_format(BIOS_GRUB)

